summaryrefslogtreecommitdiffstats
path: root/src/app
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:55:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:55:46 -0600
commit676f6ed378c861a872de8cfce3dd5efe1780f769 (patch)
treed2b21aa5311322aadc3c5c64a4932fdf371acc98 /src/app
parent2b7143e0539396c75306f6e78bf0a5641ed1acfc (diff)
downloadgwenview-676f6ed378c861a872de8cfce3dd5efe1780f769.tar.gz
gwenview-676f6ed378c861a872de8cfce3dd5efe1780f769.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 2b7143e0539396c75306f6e78bf0a5641ed1acfc.
Diffstat (limited to 'src/app')
-rw-r--r--src/app/bookmarkdialogbase.ui4
-rw-r--r--src/app/bookmarkviewcontroller.cpp6
-rw-r--r--src/app/configdialog.cpp18
-rw-r--r--src/app/configfileoperationspage.ui2
-rw-r--r--src/app/configfullscreenpage.ui4
-rw-r--r--src/app/configimagelistpage.ui12
-rw-r--r--src/app/configimageviewpage.ui8
-rw-r--r--src/app/configmiscpage.ui10
-rw-r--r--src/app/configslideshowpage.ui2
-rw-r--r--src/app/kipiinterface.cpp8
-rw-r--r--src/app/main.cpp2
-rw-r--r--src/app/mainwindow.cpp22
-rw-r--r--src/app/metaedit.cpp4
-rw-r--r--src/app/truncatedtextlabel.h8
-rw-r--r--src/app/vtabwidget.cpp6
15 files changed, 58 insertions, 58 deletions
diff --git a/src/app/bookmarkdialogbase.ui b/src/app/bookmarkdialogbase.ui
index 08ccea2..d4db944 100644
--- a/src/app/bookmarkdialogbase.ui
+++ b/src/app/bookmarkdialogbase.ui
@@ -20,7 +20,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>400</width>
<height>0</height>
@@ -88,7 +88,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>383</width>
<height>16</height>
diff --git a/src/app/bookmarkviewcontroller.cpp b/src/app/bookmarkviewcontroller.cpp
index d09156a..b40f70e 100644
--- a/src/app/bookmarkviewcontroller.cpp
+++ b/src/app/bookmarkviewcontroller.cpp
@@ -98,7 +98,7 @@ public:
if ( !item) return;
if (item->mBookmark.isGroup()) return;
- TQRect rect=mListView->itemRect(item);
+ TQRect rect=mListView->tqitemRect(item);
tip(rect, item->mBookmark.url().prettyURL());
};
@@ -392,11 +392,11 @@ void BookmarkViewController::deleteCurrentBookmark() {
TQString title;
if (bookmark.isGroup()) {
msg=i18n("Are you sure you want to delete the bookmark folder <b>%1</b>?<br>This will delete the folder and all the bookmarks in it.")
- .arg(bookmark.text());
+ .tqarg(bookmark.text());
title=i18n("Delete Bookmark &Folder");
} else {
msg=i18n("Are you sure you want to delete the bookmark <b>%1</b>?")
- .arg(bookmark.text());
+ .tqarg(bookmark.text());
title=i18n("Delete &Bookmark");
}
diff --git a/src/app/configdialog.cpp b/src/app/configdialog.cpp
index 66b11e8..0fb33df 100644
--- a/src/app/configdialog.cpp
+++ b/src/app/configdialog.cpp
@@ -22,13 +22,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
// TQt
#include <tqbuttongroup.h>
#include <tqcheckbox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlineedit.h>
#include <tqmap.h>
#include <tqradiobutton.h>
#include <tqspinbox.h>
-#include <stylesheet.h>
-#include <textedit.h>
+#include <tqstylesheet.h>
+#include <tqtextedit.h>
// KDE
#include <kcolorbutton.h>
@@ -93,9 +93,9 @@ template<class T>
void addConfigPage(KDialogBase* dialog, T* content, const TQString& header, const TQString& name, const char* iconName) {
TQFrame* page=dialog->addPage(name, header, BarIcon(iconName, 32));
content->reparent(page, TQPoint(0,0));
- TQVBoxLayout* layout=new TQVBoxLayout(page, 0, KDialog::spacingHint());
- layout->addWidget(content);
- layout->addStretch();
+ TQVBoxLayout* tqlayout=new TQVBoxLayout(page, 0, KDialog::spacingHint());
+ tqlayout->addWidget(content);
+ tqlayout->addStretch();
}
template<class T>
@@ -247,7 +247,7 @@ void ConfigDialog::calculateCacheSize() {
KURL url;
url.setPath(ThumbnailLoadJob::thumbnailBaseDir());
unsigned long size=KDirSize::dirSize(url);
- KMessageBox::information( this,i18n("Cache size is %1").arg(KIO::convertSize(size)) );
+ KMessageBox::information( this,i18n("Cache size is %1").tqarg(KIO::convertSize(size)) );
}
@@ -281,7 +281,7 @@ void ConfigDialog::emptyCache() {
int response=KMessageBox::warningContinueCancel(this,
"<qt>" + i18n("Are you sure you want to empty the thumbnail cache?"
- " This will delete the folder <b>%1</b>.").arg(TQStyleSheet::escape(dir)) + "</qt>",
+ " This will delete the folder <b>%1</b>.").tqarg(TQStyleSheet::escape(dir)) + "</qt>",
TQString(),
KStdGuiItem::del());
@@ -289,7 +289,7 @@ void ConfigDialog::emptyCache() {
KURL url;
url.setPath(dir);
- if (KIO::NetAccess::del(url, topLevelWidget()) ) {
+ if (KIO::NetAccess::del(url, tqtopLevelWidget()) ) {
KMessageBox::information( this,i18n("Cache emptied.") );
}
}
diff --git a/src/app/configfileoperationspage.ui b/src/app/configfileoperationspage.ui
index 451a030..78ac6d3 100644
--- a/src/app/configfileoperationspage.ui
+++ b/src/app/configfileoperationspage.ui
@@ -93,7 +93,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>16</height>
diff --git a/src/app/configfullscreenpage.ui b/src/app/configfullscreenpage.ui
index 855869f..e7da709 100644
--- a/src/app/configfullscreenpage.ui
+++ b/src/app/configfullscreenpage.ui
@@ -43,7 +43,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>16</height>
@@ -131,7 +131,7 @@ You can use the following keywords to format the On Screen Display:
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>18</height>
diff --git a/src/app/configimagelistpage.ui b/src/app/configimagelistpage.ui
index 01cfe95..6670dbd 100644
--- a/src/app/configimagelistpage.ui
+++ b/src/app/configimagelistpage.ui
@@ -40,7 +40,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>16</height>
@@ -131,7 +131,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>0</height>
@@ -150,7 +150,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout6</cstring>
+ <cstring>tqlayout6</cstring>
</property>
<grid>
<property name="name">
@@ -166,7 +166,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>20</height>
@@ -217,7 +217,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>16</height>
@@ -258,7 +258,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout7</cstring>
+ <cstring>tqlayout7</cstring>
</property>
<hbox>
<property name="name">
diff --git a/src/app/configimageviewpage.ui b/src/app/configimageviewpage.ui
index 963f13d..a99b945 100644
--- a/src/app/configimageviewpage.ui
+++ b/src/app/configimageviewpage.ui
@@ -56,7 +56,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>181</width>
<height>21</height>
@@ -73,7 +73,7 @@
</widget>
<widget class="TQLayoutWidget" row="4" column="0" rowspan="1" colspan="6">
<property name="name">
- <cstring>layout4</cstring>
+ <cstring>tqlayout4</cstring>
</property>
<hbox>
<property name="name">
@@ -217,7 +217,7 @@
<string>Using this option, Gwenview will display the image as fast as possible, and smooth it after a short delay.
Use this option if your computer is not very fast.</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignTop</set>
</property>
<property name="buddy" stdset="0">
@@ -238,7 +238,7 @@ Use this option if your computer is not very fast.</string>
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>16</height>
diff --git a/src/app/configmiscpage.ui b/src/app/configmiscpage.ui
index 7e5874e..9b69c2d 100644
--- a/src/app/configmiscpage.ui
+++ b/src/app/configmiscpage.ui
@@ -92,7 +92,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>24</height>
@@ -120,7 +120,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>24</height>
@@ -137,7 +137,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<grid>
<property name="name">
@@ -153,7 +153,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>11</width>
<height>20</height>
@@ -191,7 +191,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>41</height>
diff --git a/src/app/configslideshowpage.ui b/src/app/configslideshowpage.ui
index ccf0c15..62ab807 100644
--- a/src/app/configslideshowpage.ui
+++ b/src/app/configslideshowpage.ui
@@ -88,7 +88,7 @@ When this option is enabled, the slideshow will stop on the last image of the fo
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>180</width>
<height>20</height>
diff --git a/src/app/kipiinterface.cpp b/src/app/kipiinterface.cpp
index f95fe54..9a35ef3 100644
--- a/src/app/kipiinterface.cpp
+++ b/src/app/kipiinterface.cpp
@@ -163,7 +163,7 @@ KIPI::ImageCollection KIPIInterface::currentSelection() {
LOG("");
KURL::List list=d->mFileView->selectedImageURLs();
KURL url=d->mFileView->dirURL();
- return KIPI::ImageCollection(new ImageCollection(url, i18n("%1 (Selected Images)").arg(url.fileName()), list));
+ return KIPI::ImageCollection(new ImageCollection(url, i18n("%1 (Selected Images)").tqarg(url.fileName()), list));
}
@@ -189,12 +189,12 @@ int KIPIInterface::features() const {
* here, it is however necessary to discard caches if the plugin preserves timestamp
*/
bool KIPIInterface::addImage(const KURL& url, TQString&) {
- Cache::instance()->invalidate( url );
+ Cache::instance()->tqinvalidate( url );
return true;
}
void KIPIInterface::delImage(const KURL& url) {
- Cache::instance()->invalidate( url );
+ Cache::instance()->tqinvalidate( url );
}
// TODO currently KDirWatch doesn't have watching of files in a directory
@@ -203,7 +203,7 @@ void KIPIInterface::refreshImages( const KURL::List& urls ) {
for( KURL::List::ConstIterator it = urls.begin();
it != urls.end();
++it ) {
- Cache::instance()->invalidate( *it );
+ Cache::instance()->tqinvalidate( *it );
}
d->mFileView->refreshItems( urls );
}
diff --git a/src/app/main.cpp b/src/app/main.cpp
index 989bffd..bef08ae 100644
--- a/src/app/main.cpp
+++ b/src/app/main.cpp
@@ -117,7 +117,7 @@ KDE_EXPORT int kdemain (int argc, char *argv[]) {
aboutData.addCredit("Marco Gazzetta", I18N_NOOP("Fixed crash when trying to generate a thumbnail for a broken JPEG file (v0.16.0)"), "mililani@pobox.com");
aboutData.addCredit("GeniusR13", I18N_NOOP("Fixed compilation on KDE 3.0 (v0.16.1)"), "geniusr13@gmx.net");
aboutData.addCredit("Ian Koenig", I18N_NOOP("First RPM spec file"), "iguy@ionsphere.org");
- aboutData.addCredit("Meni Livne", I18N_NOOP("Toolbar layout patch for RTL languages (v0.16.0)"), "livne@kde.org");
+ aboutData.addCredit("Meni Livne", I18N_NOOP("Toolbar tqlayout patch for RTL languages (v0.16.0)"), "livne@kde.org");
aboutData.addCredit("Angelo Naselli", I18N_NOOP("Printing support (v1.0.0)"), "anaselli@linux.it");
aboutData.addCredit("Jos van den Oever", I18N_NOOP("File info view (v1.0.0)\nPatch to toggle auto-zoom on click (v1.0.0)"), "jos@vandenoever.info");
aboutData.addCredit("Jeroen Peters", I18N_NOOP("Configurable mouse wheel behavior (v1.1.1)"), "jpeters@coldmail.nl");
diff --git a/src/app/metaedit.cpp b/src/app/metaedit.cpp
index ff31891..3fa9e19 100644
--- a/src/app/metaedit.cpp
+++ b/src/app/metaedit.cpp
@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
// TQt
#include <tqlabel.h>
-#include <textedit.h>
+#include <tqtextedit.h>
#include <tqfileinfo.h>
// KDE
@@ -132,7 +132,7 @@ void MetaEdit::setComment(const TQString& comment) {
void MetaEdit::setMessage(const TQString& msg) {
mCommentEdit->setTextFormat(TQTextEdit::RichText);
mCommentEdit->setReadOnly(true);
- mCommentEdit->setText(TQString("<i>%1</i>").arg(msg));
+ mCommentEdit->setText(TQString("<i>%1</i>").tqarg(msg));
}
} // namespace
diff --git a/src/app/truncatedtextlabel.h b/src/app/truncatedtextlabel.h
index 2351890..8e126ed 100644
--- a/src/app/truncatedtextlabel.h
+++ b/src/app/truncatedtextlabel.h
@@ -39,14 +39,14 @@ public:
TruncatedTextLabel(TQWidget* parent)
: TQLabel(parent) {}
- TQSize minimumSizeHint() const {
- TQSize size=TQLabel::minimumSizeHint();
+ TQSize tqminimumSizeHint() const {
+ TQSize size=TQLabel::tqminimumSizeHint();
size.setWidth(-1);
return size;
}
- TQSize sizeHint() const {
- return TQSize(contentsRect().width(), TQLabel::sizeHint().height());
+ TQSize tqsizeHint() const {
+ return TQSize(contentsRect().width(), TQLabel::tqsizeHint().height());
}
void setText(const TQString& text) {
diff --git a/src/app/vtabwidget.cpp b/src/app/vtabwidget.cpp
index 40a1a0a..66e9b9e 100644
--- a/src/app/vtabwidget.cpp
+++ b/src/app/vtabwidget.cpp
@@ -47,9 +47,9 @@ VTabWidget::VTabWidget(TQWidget* parent)
d->mTabBar->setPosition(KMultiTabBar::Left);
d->mTabBar->setStyle(KMultiTabBar::KDEV3ICON);
d->mStack=new TQWidgetStack(this);
- TQHBoxLayout* layout=new TQHBoxLayout(this);
- layout->add(d->mTabBar);
- layout->add(d->mStack);
+ TQHBoxLayout* tqlayout=new TQHBoxLayout(this);
+ tqlayout->add(d->mTabBar);
+ tqlayout->add(d->mStack);
}
diff --git a/src/app/mainwindow.cpp b/src/app/mainwindow.cpp
index 70b42d7..1464a09 100644
--- a/src/app/mainwindow.cpp
+++ b/src/app/mainwindow.cpp
@@ -199,8 +199,8 @@ bool MainWindow::queryClose() {
KConfig* config=KGlobal::config();
// Don't store dock layout if only the image dock is visible. This avoid
// saving layout when in "fullscreen" or "image only" mode.
if (mFileViewController->isVisible() || mDirViewController->widget()->isVisible()) {
mDockArea->writeDockConfig(config,CONFIG_DOCK_GROUP);
}
@@ -806,7 +806,7 @@ void MainWindow::updateStatusInfo() {
int pos = mFileViewController->shownFilePosition();
uint count = mFileViewController->fileCount();
if (count > 0) {
- tokens << i18n("%1/%2").arg(pos+1).arg(count);
+ tokens << i18n("%1/%2").tqarg(pos+1).tqarg(count);
} else {
tokens << i18n("No images");
}
@@ -816,7 +816,7 @@ void MainWindow::updateStatusInfo() {
TQSize size = mDocument->image().size();
if (!size.isEmpty()) {
- tokens << i18n("%1 x %2 pixels").arg(size.width()).arg(size.height());
+ tokens << i18n("%1 x %2 pixels").tqarg(size.width()).tqarg(size.height());
}
mSBDetailLabel->setText(tokens.join(" - "));
@@ -867,11 +867,11 @@ void MainWindow::createWidgets() {
mDockArea->manager()->setSplitterOpaqueResize(true);
mViewModeWidget=new TQWidget(mCentralStack);
- TQVBoxLayout* layout=new TQVBoxLayout(mViewModeWidget);
- layout->setAutoAdd(true);
+ TQVBoxLayout* tqlayout=new TQVBoxLayout(mViewModeWidget);
+ tqlayout->setAutoAdd(true);
mCentralStack->addWidget(mViewModeWidget);
- // Status bar
+ // tqStatus bar
mSBDetailLabel=new TQLabel("", statusBar());
mSBHintLabel=new TruncatedTextLabel(statusBar());
@@ -923,7 +923,7 @@ void MainWindow::createWidgets() {
setGeometry(20,20,720,520);
// Default dock config
// (The "magic numbers" were found by adjusting the layout from within the
// app and looking at the result in the configuration file)
mFolderDock->manualDock(mFileDock, KDockWidget::DockLeft, 4000);
mImageDock->manualDock(mFolderDock, KDockWidget::DockBottom, 3734);
@@ -1094,9 +1094,9 @@ void MainWindow::createObjectInteractions() {
void MainWindow::createHideShowAction(KDockWidget* dock) {
TQString caption;
if (dock->mayBeHide()) {
- caption=i18n("Hide %1").arg(dock->caption());
+ caption=i18n("Hide %1").tqarg(dock->caption());
} else {
- caption=i18n("Show %1").arg(dock->caption());
+ caption=i18n("Show %1").tqarg(dock->caption());
}
KAction* action=new KAction(caption, 0, TQT_TQOBJECT(dock), TQT_SLOT(changeHideShowState()), (TQObject*)0 );
@@ -1216,7 +1216,7 @@ void MainWindow::createLocationToolBar() {
// Do not let the combobox get wider than available space, as this would
// hide the toolbuttons after it
- mURLEdit->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed);
+ mURLEdit->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed);
// Avoid stealing focus
mURLEdit->setFocusPolicy(TQ_ClickFocus);
@@ -199,8 +199,8 @@ bool MainWindow::queryClose() {
KConfig* config=KGlobal::config();
- // Don't store dock layout if only the image dock is visible. This avoid
- // saving layout when in "fullscreen" or "image only" mode.
+ // Don't store dock tqlayout if only the image dock is visible. This avoid
+ // saving tqlayout when in "fullscreen" or "image only" mode.
if (mFileViewController->isVisible() || mDirViewController->widget()->isVisible()) {
mDockArea->writeDockConfig(config,CONFIG_DOCK_GROUP);
@@ -923,7 +923,7 @@ void MainWindow::createWidgets() {
setGeometry(20,20,720,520);
// Default dock config
- // (The "magic numbers" were found by adjusting the layout from within the
+ // (The "magic numbers" were found by adjusting the tqlayout from within the
// app and looking at the result in the configuration file)
mFolderDock->manualDock(mFileDock, KDockWidget::DockLeft, 4000);